//
//  MyTrackTab.h
//  XNJB
//
//  Created by Richard Low on 04/09/2004.
//

#import <Cocoa/Cocoa.h>
#import "MyTab.h"

@interface MyTableTab : MyTab {
  IBOutlet NSTableView *njbTable;
	IBOutlet NSTextField *njbSearchField;
	NSDictionary *sortSelectors;
	NSString *currentColumnID;
	sortDirections currentSortDirection; 
	MyMutableArray *fullItemArray;
	MyMutableArray *truncatedItemArray;
	SEL oldSortSelector;
}
- (void)clearSortingArrows;
- (int)numberOfRowsInTableView:(NSTableView *)aTableView;
- (id)tableView:(NSTableView *)aTableView
		objectValueForTableColumn:(NSTableColumn *)aTableColumn
						row:(int)rowIndex;
- (void)searchNJBTable;
- (MyMutableArray *)itemArrayDisplaying;
- (SEL)sortSelectorForColumn:(NSString *)columnID;
- (MyMutableArray *)fullItemArray;
- (IBAction)searchNJBTableAction:(id)sender;
@end
